@@ -7,6 +7,8 @@ from .iam_client import HuaweiIamClient
 from .ims_client import HuaweiImsClient
 from .vpc_client import HuaweiVpcClient
 from .bss_client import HuaweiBssClient
+from .rds_client import HuaweiRdsClient
+
 prod_mapper = {
     'ecs': HuaweiEcsClient,
     'eip': HuaweiEipClient,
@@ -14,7 +16,8 @@ prod_mapper = {
     'iam': HuaweiIamClient,
     'ims': HuaweiImsClient,
     'vpc': HuaweiVpcClient,
-    'bss': HuaweiBssClient
+    'bss': HuaweiBssClient,
+    'rds': HuaweiRdsClient
 }
 
 def get_current_client(prod):
@@ -57,3 +60,8 @@ def hw_vpc_client():
 @proxy
 def hw_bss_client():
     return get_current_client('bss')
+
+
+@proxy
+def hw_rds_client():
+    return get_current_client('rds')
